#!/bin/bash
#set -x 

usage() {
    echo "This command will process sbprofile data and create a summary output"
    echo ""
    echo "LiveViewLoader -t LiveViewTable -f FeedSimFile.sbfs [ -s LiveViewServer ] [ -p StreamBasePort ]"
    echo ""
    echo "Options:"
    echo "-t <LiveViewTable> - LiveView table to publish data to"
    echo "-f <FeedSimFile.sbfs> - FeedSim file that has the data to publish"
    echo "-s <LiveViewServer> - The node name of the LiveView server"
    echo "-p <StreamBasePort> - The StreamBase port of the LiveView server (NOT the LiveView port number)"
    echo "-h - list help"
    exit -1
}

if [ $# -lt 1 ] ; then
    echo "You need to supply LiveViewTable and FeedSimFile.sbfs"
    echo ""
    usage
fi

install_path=`dirname $0`

# If running in cygwin, get the correct windows path
this_platform=`uname | cut -c 1-6`
if [ "$this_platform" = "CYGWIN" ] ; then
    install_path=`cygpath -aw "$install_path"`
fi

export STREAMBASE_LIVEVIEW_TABLE=""
export STREAMBASE_LIVEVIEW_FEEDCONFIG=""

export STREAMBASE_LIVEVIEW_SERVER=""
export STREAMBASE_PORT=""
export STREAMBASE_LIVEVIEW_MAXTUPLES=""

while [ "$1x" != "x" ] ; do

    if [ "$1" = "-h" ]; then
        usage
    fi
    if [ "$1" = "--help" ]; then
        usage
    fi
    if [ "$1" = "?" ]; then
        usage
    fi
    if [ "$1" = "-?" ]; then
        usage
    fi
    
    if [ "$1" = "-t" ]; then
        shift
        STREAMBASE_LIVEVIEW_TABLE=$1
        shift
        continue
    fi
    
    if [ "$1" = "-f" ]; then
        shift
        STREAMBASE_LIVEVIEW_FEEDCONFIG=$1
        shift
        continue
    fi

    if [ "$1" = "-s" ]; then
        shift
        STREAMBASE_LIVEVIEW_SERVER=$1
        shift
        continue
    fi

    if [ "$1" = "-l" ]; then
        shift
        STREAMBASE_LIVEVIEW_MAXTUPLES=$1
        shift
        continue
    fi

    echo "Unknown option"
    usage
done


sbd -f $install_path/sbd.sbconf $install_path/LiveViewLoader.sbapp
